@@ -11,7 +11,8 @@ use Module::Install::AutoLicense 0.08 ();
 use Module::Install::AutoManifest 0 ();
 use Module::Install::ReadmeFromPod 0.12 ();
 use Module::Install::StandardDocuments ();
-use Module::Install::Copyright 0.003 ();
+use Module::Install::Copyright 0.004 ();
+use Module::Install::Credits 0.004 ();
 use Module::Install::RDF 0.008 ();
 use Module::Install::DOAP 0.002 ();
 use Module::Install::DOAPChangeSets 0.203 ();
@@ -20,7 +21,7 @@ use Log::Log4perl 0 qw(:easy);
 
 BEGIN {
 	$Module::Package::RDF::AUTHORITY = 'cpan:TOBYINK';
-	$Module::Package::RDF::VERSION   = '0.011';
+	$Module::Package::RDF::VERSION   = '0.012';
 }
 
 use Moo;
@@ -42,6 +43,7 @@ sub main
 	$self->post_all_from(sub {Log::Log4perl->easy_init($ERROR);$self->mi->write_doap_changes});
 	$self->post_all_from(sub {$self->mi->auto_license});
 	$self->post_all_from(sub {$self->mi->write_meta_ttl});
+	$self->post_all_from(sub {$self->mi->write_credits_file});
 	$self->post_all_from(sub {$self->mi->write_copyright_file});
 	$self->post_all_from(sub {$self->mi->auto_manifest});
 	$self->post_all_from(sub {$self->mi->auto_install});
@@ -72,7 +74,7 @@ sub write_deps_list {}
 	use 5.010;
 	BEGIN {
 		$Module::Package::RDF::standard::AUTHORITY = 'cpan:TOBYINK';
-		$Module::Package::RDF::standard::VERSION   = '0.011';
+		$Module::Package::RDF::standard::VERSION   = '0.012';
 		@Module::Package::RDF::standard::ISA       = 'Module::Package::RDF';
 	};
 }
@@ -82,7 +84,7 @@ sub write_deps_list {}
 	use 5.010;
 	BEGIN {
 		$Module::Package::RDF::tobyink::AUTHORITY = 'cpan:TOBYINK';
-		$Module::Package::RDF::tobyink::VERSION   = '0.011';
+		$Module::Package::RDF::tobyink::VERSION   = '0.012';
 		@Module::Package::RDF::tobyink::ISA       = 'Module::Package::RDF';
 	};
 	sub main
@@ -134,6 +136,8 @@ In addition to the inherited behavior, this flavour uses the following plugins:
 
 =item * Copyright
 
+=item * Credits
+
 =item * DOAP
 
 =item * DOAPChangeSets
